@@ -6,7 +6,7 @@ y <- prod(x, na.rm=TRUE)
 print(y)
 z <- product(x, na.rm=TRUE)
 print(z)
-stopifnot(identical(z, y))
+stopifnot(all.equal(z, y))
 
 # Test missing values
 x <- c(1,NA,NaN,2)
@@ -14,20 +14,21 @@ y <- prod(x, na.rm=TRUE)
 print(y)
 z <- product(x, na.rm=TRUE)
 print(z)
-stopifnot(identical(z, y))
+stopifnot(all.equal(z, y))
 
 x <- c(1,NA,NaN,2)
 y <- prod(x, na.rm=FALSE)
 print(y)
 z <- product(x, na.rm=FALSE)
 print(z)
-stopifnot(identical(z, y))
+stopifnot(all(is.na(z), is.na(y)))
 
 x <- c(1,NaN,2)
 y <- prod(x, na.rm=FALSE)
 print(y)
-stopifnot(identical(y, NaN))
+stopifnot(is.na(y))
 z <- product(x, na.rm=FALSE)
 print(z)
-stopifnot(identical(z, NA_real_))
-stopifnot(!identical(z, y))
+stopifnot(is.na(z))
+
+
