@@ -17,8 +17,8 @@ for (addNA in c(FALSE, TRUE)) {
     r1 <- rowRanges(x, na.rm=na.rm)
     r2 <- colRanges(t(x), na.rm=na.rm)
     r3 <- t(apply(x, MARGIN=1, FUN=range, na.rm=na.rm))
-    stopifnot(identical(r1, r2))
-    stopifnot(identical(r1, r3))
+    stopifnot(all.equal(r1, r2))
+    stopifnot(all.equal(r1, r3))
   }
 
   # Row/column extremes
@@ -28,15 +28,15 @@ for (addNA in c(FALSE, TRUE)) {
     m1 <- rowMins(x, na.rm=na.rm)
     m2 <- colMins(t(x), na.rm=na.rm)
     m3 <- apply(x, MARGIN=1, FUN=min, na.rm=na.rm)
-    stopifnot(identical(m1, m2))
-    stopifnot(identical(m1, m3))
+    stopifnot(all.equal(m1, m2))
+    stopifnot(all.equal(m1, m3))
 
     # Max
     m1 <- rowMaxs(x, na.rm=na.rm)
     m2 <- colMaxs(t(x), na.rm=na.rm)
     m3 <- apply(x, MARGIN=1, FUN=max, na.rm=na.rm)
-    stopifnot(identical(m1, m2))
-    stopifnot(identical(m1, m3))
+    stopifnot(all.equal(m1, m2))
+    stopifnot(all.equal(m1, m3))
   }
 } # for (addNA ...)
 
@@ -52,8 +52,8 @@ for (na.rm in c(FALSE, TRUE)) {
   suppressWarnings({
     r3 <- t(apply(x, MARGIN=1, FUN=range, na.rm=na.rm))
   })
-  stopifnot(identical(r1, r2))
-  stopifnot(identical(r1, r3))
+  stopifnot(all.equal(r1, r2))
+  stopifnot(all.equal(r1, r3))
 }
 
 
@@ -64,20 +64,20 @@ for (na.rm in c(FALSE, TRUE)) {
 x <- matrix(double(0L), nrow=5L, ncol=0L)
 r1 <- rowRanges(x)
 rT <- matrix(c(Inf,-Inf), nrow=nrow(x), ncol=2L, byrow=TRUE)
-stopifnot(identical(r1,rT))
+stopifnot(all.equal(r1,rT))
 
 # 0xN matrix
 x <- t(x)
 r1 <- colRanges(x)
-stopifnot(identical(r1,rT))
+stopifnot(all.equal(r1,rT))
 
 # Nx1 matrix
 x <- matrix(1:5, nrow=5L, ncol=1L)
 r1 <- rowRanges(x)
 rT <- matrix(1:5, nrow=nrow(x), ncol=2L, byrow=FALSE)
-stopifnot(identical(r1,rT))
+stopifnot(all.equal(r1,rT))
 
 # 1xN matrix
 x <- t(x)
 r1 <- colRanges(x)
-stopifnot(identical(r1,rT))
+stopifnot(all.equal(r1,rT))
